@@ -1,11 +1,8 @@
 pcrGOF <- function(object, PRESS = FALSE)
 {
   retList <- list(Rsq = Rsq(object), Rsq.ad = Rsq.ad(object), AIC = AIC(object), 
-            AICc = AICc(object), BIC = BIC(object), HQIC = HQIC(object), 
-            resVar = resVar(object), RMSE = RMSE(object))    
-  
-  p.neill <- try(neill.test(object), silent = TRUE)
-  if (!inherits(p.neill, "try-error") & !is.na(p.neill)) retList <- c(retList, p.neill = p.neill) 
+                  AICc = AICc(object), BIC = BIC(object), resVar = resVar(object), 
+                  RMSE = RMSE(object))    
   
   fcsq <- try(fitchisq(object), silent = TRUE)
   if (!inherits(fcsq, "try-error") & !is.na(fcsq)) retList <- c(retList, chi2.red = fcsq$chi2.red)
